# widget

## Development installation

You need to install the JavaScript dependencies and run the development server.

```sh
npm install
npm run dev
```

Then open JupyterLab, VS Code, or your favorite editor
to start developing. Changes made in `js/` will be reflected
in the notebook.
